@@ -3,9 +3,9 @@ import sys
 import typing as t
 from pathlib import Path
 
-from config.core import LOG_DIR, config
-from pipeline import heart_pipe, k_neighbors_step, logit_step, svc_step, tree_step
-from processing.data_manager import load_dataset, save_pipeline
+from heart_model.config.core import LOG_DIR, config
+from heart_model.pipeline import heart_pipe, k_neighbors_step, logit_step, svc_step, tree_step
+from heart_model.processing.data_manager import load_dataset, save_pipeline
 from sklearn.metrics import accuracy_score, roc_auc_score
 from sklearn.model_selection import train_test_split
 
